@@ -153,6 +153,7 @@ class RedisForeignKey(RedisNumber):
     def clean(self):
         self.value = self.check_value()
         if self.value not in [None, 'null']:
+            print(get_ids_from_untyped_data(self.value)[0])
             self.value = get_ids_from_untyped_data(self.value)[0]
         return super().clean()
 
@@ -174,11 +175,13 @@ class RedisForeignKey(RedisNumber):
             value = super().deserialize_value(value, redis_root)
             check_types(value, int)
             if self.save_related_models:
+                print(value, self._get_instance_by_id(value, redis_root))
                 value = self._get_instance_by_id(value, redis_root)
             else:
                 value = {
                     'django_id': value
                 }
+
         return value
 
 
